==> magic3_1.10.19_src.tar.gz: magic3/include/common/scriptLibInfo.php <==
<?php
/**
 * Javascriptライブラリ情報クラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2010 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: scriptLibInfo.php 3051 2010-04-22 03:46:50Z fishbone $
 * @link       http://www.magic3.org
 */
class ScriptLibInfo
{
	// Javascriptライブラリ(DBでの設定値)
	const LIB_JQUERY_EASING			= 'jquery.easing';
	const LIB_JQUERY_JCAROUSEL		= 'jquery.jcarousel';
	const LIB_JQUERY_THICKBOX		= 'jquery.thickbox';
	const LIB_JQUERY_JSHOTKEYS		= 'jquery.jshotkeys';
	const LIB_JQUERY_CYCLE			= 'jquery.cycle';
	const LIB_JQUERY_CODEPRESS		= 'jquery.codepress';
	const LIB_JQUERY_CLUETIP		= 'jquery.cluetip';
	const LIB_JQUERY_SIMPLETREE		= 'jquery.simpletree';
	const LIB_JQUERY_BGIFRAME		= 'jquery.bgiframe';
	const LIB_JQUERY_HOVERINTENT	= 'jquery.hoverintent';
	const LIB_JQUERY_TABLEDND		= 'jquery.tablednd';
	const LIB_JQUERY_SIMPLEMODAL	= 'jquery.simplemodal';
	const LIB_JQUERY_COOKIE			= 'jquery.cookie';
	const LIB_JQUERY_FORMAT			= 'jquery.format';
	
	const LIB_JQUERY_UI				= 'jquery-ui';
	const LIB_JQUERY_UI_PLUS		= 'jquery-ui-plus';
	const LIB_FCKEDITOR				= 'fckeditor';
	const LIB_MD5					= 'md5';
	
	// Javascriptライブラリ用のファイル
	const JQUERY_EASING_FILENAME		= 'jquery/jquery.easing.1.3.js';
	//const JQUERY_JCAROUSEL_FILENAME	= 'jquery/jquery.jcarousel.pack.js';
	const JQUERY_JCAROUSEL_FILENAME		= 'jquery/jquery.jcarousel.0.2.3.pack_fixed.js';
	const JQUERY_JCAROUSEL_CSS			= 'jquery/jquery.jcarousel.css';
	const JQUERY_CONTEXTMENU_FILENAME	= 'jquery/jquery.contextmenu.r2.packed.js';
	const JQUERY_THICKBOX_FILENAME		= 'jquery/thickbox-compressed.js';
	const JQUERY_THICKBOX_CSS			= 'jquery/thickbox.css';
	const JQUERY_JSHOTKEYS_FILENAME		= 'jquery/jquery.hotkeys.js';
	const JQUERY_CYCLE_FILENAME			= 'jquery/jquery.cycle.all.pack.js';
	const JQUERY_CODEPRESS_FILENAME		= 'jquery/jquery.Codepress.js';
	const JQUERY_CLUETIP_FILENAME		= 'jquery/jquery.cluetip.js';
	const JQUERY_CLUETIP_CSS			= 'jquery/jquery.cluetip.css';
	const JQUERY_SIMPLETREE_FILENAME	= 'jquery/jquery.simple.tree.js';
	const JQUERY_SIMPLETREE_CSS			= 'jquery/simple.tree.css';
	const JQUERY_BGIFRAME_FILENAME		= 'jquery/jquery.bgiframe.min.js';
	const JQUERY_HOVERINTENT_FILENAME	= 'jquery/jquery.hoverIntent.min.js';
	const JQUERY_TABLEDND_FILENAME		= 'jquery/jquery.tablednd_0_5.js';
	const JQUERY_TABLEDND_CSS			= 'jquery/jquery.tablednd.css';
	const JQUERY_SIMPLEMODAL_FILENAME	= 'jquery/jquery.simplemodal-1.2.3.pack.js';
	const JQUERY_COOKIE_FILENAME		= 'jquery/jquery.cookie.js';
	const JQUERY_FORMAT_FILENAME		= 'jquery/jquery.format.1.03.js';
	
	// ファイル名
	const JQUERY_FILENAME			= 'jquery-1.2.6.pack.js';						// JQuery
	const JQUERY_UI_CORE_FILENAME	= 'jquery-ui-core-1.5.2.packed.js';				// JQuery UI Core (core+Interaction)
	const JQUERY_UI_PLUS_FILENAME	= 'jquery-ui-plus-1.5.2.packed.js';				// JQuery UI Core (widgets+effects)
	const JQUERY_L_FILENAME			= 'jquery-1.4.1.min.js';						// JQuery最新版(v1.4.1)
	const JQUERY_L_UI_CORE_FILENAME	= 'jquery-ui-core-1.7.2.min.js';				// JQuery UI Core (core+Interaction)
	const JQUERY_L_UI_ALL_FILENAME	= 'jquery-ui-all-1.7.2.min.js';					// JQuery UI All  (core+Interaction+widgets+effects)
	const FCKEDITOR_FILENAME		= 'fckeditor2.6/fckeditor.js';		// FCKEditor
	const MD5_FILENAME				= 'md5.js';		// MD5
	
	// 設定ファイル
	//const FCKEDITOR_CONFIG			= 'm3/fckconfig.js';		// FCKEditor
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
	}
	
	/**
	 * ライブラリ情報取得
	 *
	 * @return array		ライブラリ情報
	 */
	function getLib()
	{
		$libs = array(self::LIB_MD5					=>	array(	'script' => array(self::MD5_FILENAME)),			// MD5
					self::LIB_FCKEDITOR				=>	array(	'script' => array(self::FCKEDITOR_FILENAME)),	// FCKEditor
					self::LIB_JQUERY_UI				=>	array(	'script' => array(self::JQUERY_UI_CORE_FILENAME)),	// jquery ui
					self::LIB_JQUERY_UI_PLUS		=>	array(	'script' => array(self::JQUERY_UI_PLUS_FILENAME)),	// jquery ui plus(追加分)
					self::LIB_JQUERY_EASING			=>	array(	'script' => array(self::JQUERY_EASING_FILENAME)),		// jquery.easing用のファイル
					self::LIB_JQUERY_JCAROUSEL		=>	array(	'script' => array(self::JQUERY_JCAROUSEL_FILENAME),// jquery.jcarousel用のファイル
																'css'	=> array(self::JQUERY_JCAROUSEL_CSS)),
					self::LIB_JQUERY_THICKBOX		=>	array(	'script' => array(self::JQUERY_THICKBOX_FILENAME),// jquery.thickbox用のファイル
																'css'	=> array(self::JQUERY_THICKBOX_CSS)),
					self::LIB_JQUERY_JSHOTKEYS		=>	array(	'script' => array(self::JQUERY_JSHOTKEYS_FILENAME)),	// jquery.js-hotkeys用のファイル
					self::LIB_JQUERY_CYCLE			=>	array(	'script' => array(self::JQUERY_CYCLE_FILENAME)),		// jquery.cycle用のファイル
					self::LIB_JQUERY_CODEPRESS		=>	array(	'script' => array(self::JQUERY_CODEPRESS_FILENAME)),	// jquery.codepress用のファイル
					self::LIB_JQUERY_CLUETIP		=>	array(	'script' => array(self::JQUERY_CLUETIP_FILENAME),// jquery.cluetip用のファイル
																'css'	=> array(self::JQUERY_CLUETIP_CSS)),
					self::LIB_JQUERY_SIMPLETREE		=>	array(	'script' => array(self::JQUERY_SIMPLETREE_FILENAME),// jquery.simpletree用のファイル
																'css'	=> array(self::JQUERY_SIMPLETREE_CSS)),
					self::LIB_JQUERY_BGIFRAME		=>	array(	'script' => array(self::JQUERY_BGIFRAME_FILENAME)),	// jquery.bgiframe用のファイル
					self::LIB_JQUERY_HOVERINTENT	=>	array(	'script' => array(self::JQUERY_HOVERINTENT_FILENAME)),
					self::LIB_JQUERY_TABLEDND		=>	array(	'script' => array(self::JQUERY_TABLEDND_FILENAME),	// jquery.tablednd用のファイル
																'css'	=> array(self::JQUERY_TABLEDND_CSS)),
					self::LIB_JQUERY_SIMPLEMODAL	=>	array(	'script' => array(self::JQUERY_SIMPLEMODAL_FILENAME)),// jquery.simplemodal用のファイル
					self::LIB_JQUERY_COOKIE			=>	array(	'script' => array(self::JQUERY_COOKIE_FILENAME)),
					self::LIB_JQUERY_FORMAT			=>	array(	'script' => array(self::JQUERY_FORMAT_FILENAME)));
		return $libs;
	}
}
?>

==> magic3_1.10.21_src.tar.gz: magic3/include/common/scriptLibInfo.php <==
<?php
/**
 * Javascriptライブラリ情報クラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2010 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: scriptLibInfo.php 3067 2010-04-24 08:56:38Z fishbone $
 * @link       http://www.magic3.org
 */
class ScriptLibInfo
{
	// Javascriptライブラリ(DBでの設定値)
	const LIB_JQUERY_EASING			= 'jquery.easing';
	const LIB_JQUERY_JCAROUSEL		= 'jquery.jcarousel';
	const LIB_JQUERY_THICKBOX		= 'jquery.thickbox';
	const LIB_JQUERY_JSHOTKEYS		= 'jquery.jshotkeys';
	const LIB_JQUERY_CYCLE			= 'jquery.cycle';
	const LIB_JQUERY_CODEPRESS		= 'jquery.codepress';
	const LIB_JQUERY_CLUETIP		= 'jquery.cluetip';
	const LIB_JQUERY_SIMPLETREE		= 'jquery.simpletree';
	const LIB_JQUERY_BGIFRAME		= 'jquery.bgiframe';
	const LIB_JQUERY_HOVERINTENT	= 'jquery.hoverintent';
	const LIB_JQUERY_TABLEDND		= 'jquery.tablednd';
	const LIB_JQUERY_SIMPLEMODAL	= 'jquery.simplemodal';
	const LIB_JQUERY_COOKIE			= 'jquery.cookie';
	const LIB_JQUERY_FORMAT			= 'jquery.format';
	const LIB_JQUERY_FORMTIPS		= 'jquery.formtips';
	
	const LIB_JQUERY_UI				= 'jquery-ui';
	const LIB_JQUERY_UI_PLUS		= 'jquery-ui-plus';
	const LIB_FCKEDITOR				= 'fckeditor';
	const LIB_MD5					= 'md5';
	
	// Javascriptライブラリ用のファイル
	const JQUERY_EASING_FILENAME		= 'jquery/jquery.easing.1.3.js';
	//const JQUERY_JCAROUSEL_FILENAME	= 'jquery/jquery.jcarousel.pack.js';
	const JQUERY_JCAROUSEL_FILENAME		= 'jquery/jquery.jcarousel.0.2.3.pack_fixed.js';
	const JQUERY_JCAROUSEL_CSS			= 'jquery/jquery.jcarousel.css';
	const JQUERY_CONTEXTMENU_FILENAME	= 'jquery/jquery.contextmenu.r2.packed.js';
	const JQUERY_THICKBOX_FILENAME		= 'jquery/thickbox-compressed.js';
	const JQUERY_THICKBOX_CSS			= 'jquery/thickbox.css';
	const JQUERY_JSHOTKEYS_FILENAME		= 'jquery/jquery.hotkeys.js';
	const JQUERY_CYCLE_FILENAME			= 'jquery/jquery.cycle.all.pack.js';
	const JQUERY_CODEPRESS_FILENAME		= 'jquery/jquery.Codepress.js';
	const JQUERY_CLUETIP_FILENAME		= 'jquery/jquery.cluetip.js';
	const JQUERY_CLUETIP_CSS			= 'jquery/jquery.cluetip.css';
	const JQUERY_SIMPLETREE_FILENAME	= 'jquery/jquery.simple.tree.js';
	const JQUERY_SIMPLETREE_CSS			= 'jquery/simple.tree.css';
	const JQUERY_BGIFRAME_FILENAME		= 'jquery/jquery.bgiframe.min.js';
	const JQUERY_HOVERINTENT_FILENAME	= 'jquery/jquery.hoverIntent.min.js';
	const JQUERY_TABLEDND_FILENAME		= 'jquery/jquery.tablednd_0_5.js';
	const JQUERY_TABLEDND_CSS			= 'jquery/jquery.tablednd.css';
	const JQUERY_SIMPLEMODAL_FILENAME	= 'jquery/jquery.simplemodal-1.2.3.pack.js';
	const JQUERY_COOKIE_FILENAME		= 'jquery/jquery.cookie.js';
	const JQUERY_FORMAT_FILENAME		= 'jquery/jquery.format.1.03.js';
	const JQUERY_FORMTIPS_FILENAME		= 'jquery/jquery.formtips.1.2.packed.js';
	
	// ファイル名
	const JQUERY_FILENAME			= 'jquery-1.2.6.pack.js';						// JQuery
	const JQUERY_UI_CORE_FILENAME	= 'jquery-ui-core-1.5.2.packed.js';				// JQuery UI Core (core+Interaction)
	const JQUERY_UI_PLUS_FILENAME	= 'jquery-ui-plus-1.5.2.packed.js';				// JQuery UI Core (widgets+effects)
	const JQUERY_L_FILENAME			= 'jquery-1.4.1.min.js';						// JQuery最新版(v1.4.1)
	const JQUERY_L_UI_CORE_FILENAME	= 'jquery-ui-core-1.7.2.min.js';				// JQuery UI Core (core+Interaction)
	const JQUERY_L_UI_ALL_FILENAME	= 'jquery-ui-all-1.7.2.min.js';					// JQuery UI All  (core+Interaction+widgets+effects)
	const FCKEDITOR_FILENAME		= 'fckeditor2.6/fckeditor.js';		// FCKEditor
	const MD5_FILENAME				= 'md5.js';		// MD5
	
	// 設定ファイル
	//const FCKEDITOR_CONFIG			= 'm3/fckconfig.js';		// FCKEditor
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
	}
	
	/**
	 * ライブラリ情報取得
	 *
	 * @return array		ライブラリ情報
	 */
	function getLib()
	{
		$libs = array(self::LIB_MD5					=>	array(	'script' => array(self::MD5_FILENAME)),			// MD5
					self::LIB_FCKEDITOR				=>	array(	'script' => array(self::FCKEDITOR_FILENAME)),	// FCKEditor
					self::LIB_JQUERY_UI				=>	array(	'script' => array(self::JQUERY_UI_CORE_FILENAME)),	// jquery ui
					self::LIB_JQUERY_UI_PLUS		=>	array(	'script' => array(self::JQUERY_UI_PLUS_FILENAME)),	// jquery ui plus(追加分)
					self::LIB_JQUERY_EASING			=>	array(	'script' => array(self::JQUERY_EASING_FILENAME)),		// jquery.easing用のファイル
					self::LIB_JQUERY_JCAROUSEL		=>	array(	'script' => array(self::JQUERY_JCAROUSEL_FILENAME),// jquery.jcarousel用のファイル
																'css'	=> array(self::JQUERY_JCAROUSEL_CSS)),
					self::LIB_JQUERY_THICKBOX		=>	array(	'script' => array(self::JQUERY_THICKBOX_FILENAME),// jquery.thickbox用のファイル
																'css'	=> array(self::JQUERY_THICKBOX_CSS)),
					self::LIB_JQUERY_JSHOTKEYS		=>	array(	'script' => array(self::JQUERY_JSHOTKEYS_FILENAME)),	// jquery.js-hotkeys用のファイル
					self::LIB_JQUERY_CYCLE			=>	array(	'script' => array(self::JQUERY_CYCLE_FILENAME)),		// jquery.cycle用のファイル
					self::LIB_JQUERY_CODEPRESS		=>	array(	'script' => array(self::JQUERY_CODEPRESS_FILENAME)),	// jquery.codepress用のファイル
					self::LIB_JQUERY_CLUETIP		=>	array(	'script' => array(self::JQUERY_CLUETIP_FILENAME),// jquery.cluetip用のファイル
																'css'	=> array(self::JQUERY_CLUETIP_CSS)),
					self::LIB_JQUERY_SIMPLETREE		=>	array(	'script' => array(self::JQUERY_SIMPLETREE_FILENAME),// jquery.simpletree用のファイル
																'css'	=> array(self::JQUERY_SIMPLETREE_CSS)),
					self::LIB_JQUERY_BGIFRAME		=>	array(	'script' => array(self::JQUERY_BGIFRAME_FILENAME)),	// jquery.bgiframe用のファイル
					self::LIB_JQUERY_HOVERINTENT	=>	array(	'script' => array(self::JQUERY_HOVERINTENT_FILENAME)),
					self::LIB_JQUERY_TABLEDND		=>	array(	'script' => array(self::JQUERY_TABLEDND_FILENAME),	// jquery.tablednd用のファイル
																'css'	=> array(self::JQUERY_TABLEDND_CSS)),
					self::LIB_JQUERY_SIMPLEMODAL	=>	array(	'script' => array(self::JQUERY_SIMPLEMODAL_FILENAME)),// jquery.simplemodal用のファイル
					self::LIB_JQUERY_COOKIE			=>	array(	'script' => array(self::JQUERY_COOKIE_FILENAME)),
					self::LIB_JQUERY_FORMAT			=>	array(	'script' => array(self::JQUERY_FORMAT_FILENAME)),
					self::LIB_JQUERY_FORMTIPS		=>	array(	'script' => array(self::JQUERY_FORMTIPS_FILENAME)));
		return $libs;
	}
}
?>
